"use client";

import React from "react";
import { useDex } from "../dex";
import { LoginFormValues, loginSchema } from "@/schemas";
import { Form, Formik } from "formik";
import PrettyForm from "@/components/PrettyForm";
import Input from "@/components/Input";

export default function DexPasswordForm({ domain }: { domain: string }) {
  const [globalError, setGlobalError] = React.useState<string | null>(null);
  const [submitting, setSubmitting] = React.useState(false);

  const sendToDex = useDex(domain, (msg) => {
    switch (msg.type) {
      case "passwordSubmitResult":
        setSubmitting(false);
        if (!msg.success) setGlobalError("Invalid credentials.");
        break;
    }
  });

  async function handleFormSubmit({ username, password }: LoginFormValues) {
    setSubmitting(true);
    sendToDex({
      type: "passwordSubmit",
      username,
      password
    });
  }

  // Stolen from LoginForm
  return (
    <PrettyForm globalError={globalError}>
      <Formik
        initialValues={{ username: "", password: "" }}
        onSubmit={handleFormSubmit}
        validationSchema={loginSchema}
      >
        {() => (
          <Form>
            <Input
              type="text"
              placeholder="julian"
              name="username"
              label="Username"
            />
            <Input
              type="password"
              placeholder="deeznuts47"
              name="password"
              label="Password"
            />
            <input type="submit" value="Login" disabled={submitting} />
          </Form>
        )}
      </Formik>
    </PrettyForm>
  );
}
